@@ -349,7 +349,7 @@ static gboolean textview_is_hyperlink_at_cursor(DictData *dd)
 
 static void textview_populate_popup_cb(GtkTextView *textview, GtkMenu *menu, DictData *dd)
 {
-	GtkWidget *box, *icon, *label;
+	GtkWidget *icon;
 
 	GtkWidget *search = gtk_menu_item_new ();
 	GtkWidget *copy_link;
@@ -360,7 +360,7 @@ static void textview_populate_popup_cb(GtkTextView *textview, GtkMenu *menu, Dic
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	copy_link = gtk_image_menu_item_new_with_mnemonic (_("Copy Link"));
-	icon = gtk_image_new_from_icon_name ("edit-copy", GTK_ICON_SIZE_MENU);
+	icon = gtk_image_new_from_icon_name ("edit-copy-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (copy_link), icon);
 G_GNUC_END_IGNORE_DEPRECATIONS
 
@@ -370,7 +370,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	search = gtk_image_menu_item_new_with_mnemonic (_("Search"));
-	icon = gtk_image_new_from_icon_name ("edit-find", GTK_ICON_SIZE_MENU);
+	icon = gtk_image_new_from_icon_name ("edit-find-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (search), icon);
 G_GNUC_END_IGNORE_DEPRECATIONS
 
@@ -580,54 +580,32 @@ static gboolean entry_button_press_cb(GtkWidget *widget, GdkEventButton *event,
 }
 
 
-static const gchar *get_icon_name(const gchar *req1, const gchar *req2, const gchar *fallback)
-{
-	GtkIconTheme *theme = gtk_icon_theme_get_default();
-
-	if (gtk_icon_theme_has_icon(theme, req1))
-		return req1;
-	else if (gtk_icon_theme_has_icon(theme, req2))
-		return req2;
-	else
-		return fallback;
-}
-
-
 static void update_search_button(DictData *dd, GtkWidget *box)
 {
 	static GtkWidget *button = NULL;
-	/* cache the image name to not lookup through the theme each time */
-	static const gchar *web_image_name = NULL;
 	GtkWidget *image = NULL;
 
 	if (button == NULL)
 	{
 		button = gtk_button_new_with_mnemonic (_("F_ind"));
 		gtk_button_set_image(GTK_BUTTON(button),
-			gtk_image_new_from_icon_name("edit-find", GTK_ICON_SIZE_BUTTON));
+			gtk_image_new_from_icon_name("edit-find-symbolic", GTK_ICON_SIZE_BUTTON));
 		gtk_widget_show(button);
 		gtk_box_pack_start(GTK_BOX(box), button, FALSE, FALSE, 0);
 		g_signal_connect(button, "clicked", G_CALLBACK(entry_button_clicked_cb), dd);
-
-		/* "internet-web-browser" is Tango, "web-browser" is Rodent, "edit-find" is GTK */
-		web_image_name = get_icon_name("internet-web-browser", "web-browser", "edit-find");
 	}
 
 	switch (dd->mode_in_use)
 	{
 		case DICTMODE_DICT:
-		{
-			image = gtk_image_new_from_icon_name("edit-find", GTK_ICON_SIZE_BUTTON);
-			break;
-		}
 		case DICTMODE_WEB:
 		{
-			image = gtk_image_new_from_icon_name(web_image_name, GTK_ICON_SIZE_BUTTON);
+			image = gtk_image_new_from_icon_name("edit-find-symbolic", GTK_ICON_SIZE_BUTTON);
 			break;
 		}
 		case DICTMODE_SPELL:
 		{
-			image = gtk_image_new_from_icon_name("tools-check-spelling", GTK_ICON_SIZE_BUTTON);
+			image = gtk_image_new_from_icon_name("tools-check-spelling-symbolic", GTK_ICON_SIZE_BUTTON);
 			break;
 		}
 		default:
@@ -699,7 +677,7 @@ static GtkWidget *create_file_menu(DictData *dd)
 	/* Speed Reader */
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	menu_item = gtk_image_menu_item_new_with_mnemonic (_("Speed _Reader"));
-	icon = gtk_image_new_from_icon_name ("format-justify-center", GTK_ICON_SIZE_MENU);
+	icon = gtk_image_new_from_icon_name ("format-justify-center-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), icon);
 G_GNUC_END_IGNORE_DEPRECATIONS
 
@@ -714,7 +692,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 	/* Preferences */
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	dd->pref_menu_item = gtk_image_menu_item_new_with_mnemonic (_("_Preferences"));
-	icon = gtk_image_new_from_icon_name ("preferences-system", GTK_ICON_SIZE_MENU);
+	icon = gtk_image_new_from_icon_name ("preferences-system-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (dd->pref_menu_item), icon);
 G_GNUC_END_IGNORE_DEPRECATIONS
 
@@ -728,13 +706,12 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 	/* Close */
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	dd->close_menu_item = gtk_image_menu_item_new_with_mnemonic (dd->is_plugin ? _("_Close") : _("_Quit"));
-	icon = gtk_image_new_from_icon_name (dd->is_plugin ? "window-close" : "application-exit", GTK_ICON_SIZE_MENU);
+	icon = gtk_image_new_from_icon_name (dd->is_plugin ? "window-close-symbolic" : "application-exit-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (dd->close_menu_item), icon);
 G_GNUC_END_IGNORE_DEPRECATIONS
 
 	gtk_widget_add_accelerator (dd->close_menu_item, "activate", accel_group,
-								dd->is_plugin ? GDK_KEY_c : GDK_KEY_q,
-								GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
+								GDK_KEY_q, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 	gtk_container_add(GTK_CONTAINER(file_menu), dd->close_menu_item);
 
 	/* Help Menu*/
@@ -746,7 +723,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
 	/* About */
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	menu_item = gtk_image_menu_item_new_with_mnemonic (_("About"));
-	icon = gtk_image_new_from_icon_name ("help-about", GTK_ICON_SIZE_MENU);
+	icon = gtk_image_new_from_icon_name ("help-about-symbolic", GTK_ICON_SIZE_MENU);
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), icon);
 G_GNUC_END_IGNORE_DEPRECATIONS
 
@@ -812,8 +789,8 @@ void dict_gui_create_main_window(DictData *dd)
 
 	dd->main_entry = gtk_bin_get_child(GTK_BIN(dd->main_combo));
 	gtk_entry_set_placeholder_text(GTK_ENTRY(dd->main_entry), _("Search term"));
-	gtk_entry_set_icon_from_icon_name(GTK_ENTRY(dd->main_entry), GTK_ENTRY_ICON_PRIMARY, "edit-find");
-	gtk_entry_set_icon_from_icon_name(GTK_ENTRY(dd->main_entry), GTK_ENTRY_ICON_SECONDARY, "edit-clear");
+	gtk_entry_set_icon_from_icon_name(GTK_ENTRY(dd->main_entry), GTK_ENTRY_ICON_PRIMARY, "edit-find-symbolic");
+	gtk_entry_set_icon_from_icon_name(GTK_ENTRY(dd->main_entry), GTK_ENTRY_ICON_SECONDARY, "edit-clear-symbolic");
 	g_signal_connect(dd->main_entry, "changed", G_CALLBACK(entry_changed_cb), dd);
 	g_signal_connect(dd->main_entry, "activate", G_CALLBACK(entry_activate_cb), dd);
 	g_signal_connect(dd->main_entry, "icon-release", G_CALLBACK(entry_icon_release_cb), dd);
@@ -827,7 +804,7 @@ void dict_gui_create_main_window(DictData *dd)
 
 	button = gtk_button_new_with_mnemonic(_("Speed _Reader"));
 	gtk_button_set_image(GTK_BUTTON(button),
-		gtk_image_new_from_icon_name("format-justify-center", GTK_ICON_SIZE_MENU));
+		gtk_image_new_from_icon_name("format-justify-center-symbolic", GTK_ICON_SIZE_MENU));
 	g_signal_connect(button, "clicked", G_CALLBACK(speedreader_clicked_cb), dd);
 	gtk_widget_show(button);
 	gtk_box_pack_start(GTK_BOX(entry_box), button, FALSE, FALSE, 2);
@@ -840,7 +817,7 @@ void dict_gui_create_main_window(DictData *dd)
 		_("_Close") : _("_Quit"));
 	gtk_button_set_image(GTK_BUTTON(dd->close_button),
 		gtk_image_new_from_icon_name((dd->is_plugin) ?
-			"window-close" : "application-exit", GTK_ICON_SIZE_BUTTON));
+			"window-close-symbolic" : "application-exit-symbolic", GTK_ICON_SIZE_BUTTON));
 	gtk_widget_show(dd->close_button);
 	gtk_box_pack_end(GTK_BOX(entry_box), dd->close_button, FALSE, FALSE, 0);
 
@@ -989,23 +966,18 @@ void dict_gui_about_dialog(GtkWidget *widget, DictData *dd)
                             "André Miranda <andre42m@gmail.com>",
                             NULL };
 
-	GdkPixbuf *logo = gdk_pixbuf_new_from_resource("/org/xfce/dict/icon", NULL);
-
 	gtk_show_about_dialog(GTK_WINDOW(dd->window),
 		"destroy-with-parent", TRUE,
 		"authors", authors,
 		"comments", _("A client program to query different dictionaries."),
-		"copyright", _("Copyright \302\251 2006-2020 Xfce Development Team"),
+		"copyright", "Copyright \302\251 2006-2023 Xfce Development Team",
 		"website", "https://docs.xfce.org/apps/xfce4-dict/start",
-		"logo", logo,
+		"logo-icon-name", "org.xfce.Dictionary",
 		"translator-credits", _("translator-credits"),
 		"license", XFCE_LICENSE_GPL,
 		"version", PACKAGE_VERSION,
 		"program-name", _("Xfce4 Dictionary"),
 		  NULL);
-
-	if (logo != NULL)
-		g_object_unref(logo);
 }
 
 
