@@ -27,7 +27,7 @@
 
 #include <libxfce4util/libxfce4util.h>
 
-#if HAVE_LOCALE_H
+#ifdef HAVE_LOCALE_H
 # include <locale.h>
 #endif
 
@@ -122,9 +122,7 @@ gint main(gint argc, gchar *argv[])
 	gchar flags;
 	gchar *search_text;
 
-#ifdef ENABLE_NLS
 	xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
-#endif
 
 	context = g_option_context_new(_("[TEXT]"));
 	g_option_context_add_main_entries(context, cli_options, GETTEXT_PACKAGE);
@@ -140,8 +138,8 @@ gint main(gint argc, gchar *argv[])
 	if (show_version)
 	{
 		g_print("%s %s (Xfce %s)\n\n", PACKAGE, PACKAGE_VERSION, xfce_version_string());
-		g_print("%s\n", "Copyright (c) 2006-2016");
-		g_print("\tEnrico Tröger <enrico@xfce.org>\n\n");
+		g_print("%s\n", "Copyright (c) 2006-2023");
+		g_print("\tXfce Development Team\n\n");
 		g_print(_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
 		g_print("\n");
 
